/* -------------------------------------------------------------------
   File "sample.pro"

   This file defines the problem dependent data structures.
   
   To compute the solution: 
       getdp_sparskit Lines -pre EleSta_v -cal

   To compute post-results:
       getdp_sparskit Lines -pos Map
    or getdp_sparskit Lines -pos Cut
   ------------------------------------------------------------------- */

Group {

  /* Elementary Groups used for Function Defs */
  epsRegion0 = Region[100000:103152];
  epsRegion0Sources = Region[102932:102943];
  epsRegion1 = Region[200000];

  /* Elementary Groups used for Constraints */
  ConstraintRegion0 = Region[1];
  ConstraintRegion1 = Region[2];

  /* Global Groups */
  SourceDomain = Region[{epsRegion0Sources}]; /* Regions with nonzero charge density */
  ConstrainedRegionsAll = Region[{ConstraintRegion0,ConstraintRegion1}]; /* All regions with constrained potentials */
  DomainCC_Ele = Region[{epsRegion0,epsRegion1}]; /* Nonconducting regions */
  DomainC_Ele = Region[{ConstraintRegion0,ConstraintRegion1}]; /* Constrained (assumed conducting) regions */
  Domain_Ele = Region[{DomainCC_Ele,DomainC_Ele}];

}


Function {

  /* Piecewise definition of relative dielectric function */
  epsr[epsRegion0] = 3.9;
  epsr[epsRegion1] = 1.0;
  epsr[ConstrainedRegionsAll] = 1.0;

  /* Piecewise definition of rho function.
   * This is the section that varies. The first
   * time GetDP is invoked, there are usually
   * few (perhaps no) regions with charge density.
   * With each new invocation the number of charged
   * regions and the values of charge density 
   * change somewhat. 
   * Note, this section has been abbreviated.
   * In practice I've had as many as 175000
   * lines in this definition. Is there an
   * easier way to do it?
   */
  rho[Region[102941]] = 1.2411497366652471E8;
  rho[Region[102940]] = 2.930550247617446E8;
  rho[Region[102943]] = 763684.3396936561;
  rho[Region[102942]] = -1181532.3746500027;
  rho[Region[102937]] = 2.528011747101411E9;
  rho[Region[102936]] = -794960.9399746975;
  rho[Region[102939]] = 9.208931158873624E7;
  rho[Region[102938]] = -8.12609172217796E7;
  rho[Region[102933]] = 1.761801370265882E8;
  rho[Region[102932]] = 2.98397019499748E7;
  rho[Region[102935]] = -285661.9751905232;
  rho[Region[102934]] = 8.103691356131545E7;

}


Constraint {

  /* Dirichlet constraints */
  { Name ElectricScalarPotential; Type Assign;
    Case {
      { Region ConstraintRegion0; Value -10.0;}
      { Region ConstraintRegion1; Value 0.0;}
    }
  }

}

/* The formulation used and its tools, considered as being 
   in a black box, can now be included */

Include "Jacobian_Lib.pro"
Include "Integration_Lib.pro"
Include "EleSta_v.pro"

/* Finally, we can define some operations to output results */

e = 1.e-7;

PostOperation {
  { Name Map; NameOfPostProcessing EleSta_v;
     Operation {
       Print [ v, OnElementsOf DomainCC_Ele, File "Lines_v.pos" ];
       //Print [ e, OnElementsOf DomainCC_Ele, File "Lines_e.pos" ];
     }
  }
  /*{ Name Cut; NameOfPostProcessing EleSta_v;
     Operation {
       Print [ e, OnLine {{e,e,0}{10.e-3,e,0}} {500}, File "Cut_e" ];
     }
  }*/

}
